@@ -85,18 +85,15 @@ class TaskAssignator:
                     if ids in self.enqueued:
                         q = 0
                         for ipt in scheduler.proc_tasks.keys():
-                            print("IPT in scheduler", ipt,
-                                  scheduler.proc_tasks)
                             q += 1
                             if len(scheduler.proc_tasks.get(ipt)) < \
                                scheduler.lnproc and \
                                ids not in sta_assigned:
                                 respuesta = {'station': ids,
                                              'core': ipt, }
-                                print("Respuest", respuesta, "DT status > %s <"
-                                      % dt_status)
                                 if dt_status == 'GROUP':
-                                    if scheduler.stations.get(ids).get(self.code_filter) in dt_group:
+                                    if scheduler.stations.get(ids).get(
+                                            self.code_filter) in dt_group:
                                         icos = scheduler.add_task(ids, ipt)
                                         scheduler.set_init(ids)
                                         ico = get_free_ico(icos)
@@ -112,8 +109,9 @@ class TaskAssignator:
                                     ico = get_free_ico(icos)
                                     scheduler.set_init(ids)
                                     qr = {ico: ids}
-                                    self.counter +=1                                    
-                                    ans = "TASK %s ADDED TO %s, de un total de:%d" % (ids, ipt, self.counter)
+                                    self.counter += 1
+                                    ans = "TASK %s ADDED TO %s, de un total de:%d" % (
+                                        ids, ipt, self.counter)
                                     sta_assigned.append(ids)
                                     self.locker.acquire()
                                     self.scheduler.add_sta_assigned(
