@@ -132,24 +132,18 @@ class TaskScheduler:
         result_args, result_kwargs = [], {}
         log = kwargs.get('log')
         try:
-            gprint("="*20)
-            rprint("Task...")
-            bprint("IPT_>%s ICO_> %s" %(ipt, ico))
-            rprint("args")
-            bprint(args)
-            gprint("="*20)
-
             if assigned_task:
                 if not self.sta_init.get(assigned_task):
                     args, kwargs = self.set_pst(assigned_task, args, kwargs)
                 result_args, result_kwargs = await shield(self.run_task(*args, **kwargs))
             else:
                 result_args, result_kwargs = args, kwargs
-            return [ipt, ico, *result_args], result_kwargs                
+            return [ipt, ico, *result_args], result_kwargs
         except Exception as e:
             if log:
-                log.exception("STA_TASK: Falla en inicializar la corutina loop, %s %s" %(args, kwargs))
-            raise e            
+                log.exception(
+                    "STA_TASK: Falla en inicializar la corutina loop, %s %s" % (args, kwargs))
+            raise e
 
     async def process_sta_task_n2s(self, ipt, ico, *args, **kwargs):
         """
@@ -170,15 +164,17 @@ class TaskScheduler:
         try:
             if assigned_task:
                 if not self.sta_init.get(assigned_task):
-                    args, kwargs = self.set_pst_n2s(assigned_task, args, kwargs)
+                    args, kwargs = self.set_pst_n2s(
+                        assigned_task, args, kwargs)
                 result_args, result_kwargs = await shield(self.n2s_coro(*args, **kwargs))
             else:
                 result_args, result_kwargs = args, kwargs
-            return [ipt, ico, *result_args], result_kwargs                
+            return [ipt, ico, *result_args], result_kwargs
         except Exception as e:
             if log:
-                log.exception("N2S: Falla en inicializar la corutina loop, %s %s" %(args, kwargs))
-            raise e            
+                log.exception(
+                    "N2S: Falla en inicializar la corutina loop, %s %s" % (args, kwargs))
+            raise e
 
     async def process_sta_task_s2n(self, ipt, ico, *args, **kwargs):
         """
@@ -194,19 +190,21 @@ class TaskScheduler:
         """
         assigned_task = self.assigned_tasks.get(ipt, {}).get(ico, None)
         result_args, result_kwargs = [], {}
-        log = kwargs.get('log')        
+        log = kwargs.get('log')
         try:
             if assigned_task:
                 if not self.sta_init[assigned_task]:
-                    args, kwargs = self.set_pst_s2n(assigned_task, args, kwargs)
+                    args, kwargs = self.set_pst_s2n(
+                        assigned_task, args, kwargs)
                 result_args, result_kwargs = await shield(self.s2n_coro(*args, **kwargs))
             else:
                 result_args, result_kwargs = args, kwargs
-            return [ipt, ico, *result_args], result_kwargs                
+            return [ipt, ico, *result_args], result_kwargs
         except Exception as e:
             if log:
-                log.exception("S2N: Falla en inicializar la corutina loop, %s %s" %(args, kwargs))
-            raise e            
+                log.exception(
+                    "S2N: Falla en inicializar la corutina loop, %s %s" % (args, kwargs))
+            raise e
 
     def get_ipt(self, ids):
         for ipt, ico_set in self.assigned_tasks.items():
